

- Add comment about slab ctor behaviour (Ingo Oeser)

- mm/slab.c:fprob() shows up in profiles a lot.  Rename it to something more
  meaningful.

- fatfs printk warning fix (Randy Dunlap)


 25-akpm/fs/fat/misc.c |    2 +-
 25-akpm/mm/slab.c     |    8 ++++++--
 2 files changed, 7 insertions(+), 3 deletions(-)

diff -puN mm/slab.c~misc3 mm/slab.c
--- 25/mm/slab.c~misc3	Tue Jun  3 16:09:02 2003
+++ 25-akpm/mm/slab.c	Tue Jun  3 16:09:02 2003
@@ -25,6 +25,10 @@
  * page long) and always contiguous), and each slab contains multiple
  * initialized objects.
  *
+ * This means, that your constructor is used only for newly allocated
+ * slabs and you must pass objects with the same intializations to
+ * kmem_cache_free.
+ *
  * Each cache can only support one memory type (GFP_DMA, GFP_HIGHMEM,
  * normal). If you need a special memory type, then must create a new
  * cache for that memory type.
@@ -782,7 +786,7 @@ static void poison_obj(kmem_cache_t *cac
 	*(unsigned char *)(addr+size-1) = POISON_END;
 }
 
-static void *fprob(unsigned char* addr, unsigned int size)
+static void *scan_poisoned_obj(unsigned char* addr, unsigned int size)
 {
 	unsigned char *end;
 	
@@ -808,7 +812,7 @@ static void check_poison_obj(kmem_cache_
 	if (cachep->flags & SLAB_STORE_USER) {
 		size -= BYTES_PER_WORD;
 	}
-	end = fprob(addr, size);
+	end = scan_poisoned_obj(addr, size);
 	if (end) {
 		int s;
 		printk(KERN_ERR "Slab corruption: start=%p, expend=%p, "
diff -puN fs/fat/misc.c~misc3 fs/fat/misc.c
--- 25/fs/fat/misc.c~misc3	Tue Jun  3 16:09:24 2003
+++ 25-akpm/fs/fat/misc.c	Tue Jun  3 16:09:46 2003
@@ -311,7 +311,7 @@ next:
 	*bh = sb_bread(sb, phys);
 	if (*bh == NULL) {
 		printk(KERN_ERR "FAT: Directory bread(block %llu) failed\n",
-		       phys);
+		       (unsigned long long)phys);
 		/* skip this block */
 		*pos = (iblock + 1) << sb->s_blocksize_bits;
 		goto next;

_
